/*
 * FILE								: evtft.c
 * DESCRIPTION				: This file is iHMI43 evtft driver.
 * Author							: XiaomaGee@Gmail.com
 * Copyright					:
 *
 * History
 * -------------------
 * Rev								: 0.00
 * Date								: 08/26/2012
 *
 * create.
 * -------------------
 */
//---------------- Include files ------------------------//

#include "..\include\hardware.h"
#include "..\include\evtft.h"
#include "..\include\color.h"

//---------------- Function Prototype -------------------//
static int initialize(void);
static int set_point(int /* x */, int /* y */, unsigned short int /* color */);
static unsigned short int get_point(int /* x */, int /* y */);
static int cls(COLOR_T c);
static int write_a(void);
static int write_b(void);
void change(void);

//---------------- Variable -----------------------------//
LCD_T lcd = {
	.initialize = initialize,
	.set_point = set_point,
	.get_point = get_point,
	.cls = cls,
	.write_a = write_a,
	.write_b = write_b,
	.change = change
};

LCD_CTL_T lcd_ctl;

//-----------------Function------------------------------//
/*
 * Name								: initialize
 * Description				: ---
 * Author							: XiaomaGee.
 *
 * History
 * -------------------
 * Rev								: 0.00
 * Date								: 08/26/2012
 * 
 * create.
 * -------------------
 */
static int
initialize(void)
{
	int i;

	lcd_ctl.w = 1;
	lcd_ctl.b.csrmode = 0;

	LCD_CTL = DISPLAY_OFF;

	LCD_ADDX = 0;
	LCD_ADDY = 0;

	for (i = 0; i < LCD_XSIZE * LCD_YSIZE; i++) LCD_DATA = 0;

	LCD_CTL = DISPLAY_ON;

	return 0;
}
/*
 * Name								: set_point
 * Description				: ---
 * Author							: XiaomaGee.
 *
 * History
 * -------------------
 * Rev								: 0.00
 * Date								: 08/26/2012
 * 
 * create.
 * -------------------
 */
static int
set_point(int x, int y, unsigned short int color)
{
	LCD_ADDX = x;
	LCD_ADDY = y;

	LCD_DATA = color;

	return 0;
}
/*
 * Name								: get_point
 * Description				: ---
 * Author							: XiaomaGee.
 *
 * History
 * -------------------
 * Rev								: 0.00
 * Date								: 08/26/2012
 * 
 * create.
 * -------------------
 */
static unsigned short int
get_point(int x, int y)
{
	LCD_ADDX = x;
	LCD_ADDY = y;

	return LCD_DATA;
}
/*
 * Name								: cls
 * Description				: ---
 * Author							: XiaomaGee.
 *
 * History
 * -------------------
 * Rev								: 0.00
 * Date								: 08/26/2012
 * 
 * create.
 * -------------------
 */
static int
cls(COLOR_T c)
{
	int i;

	lcd_ctl.b.csrmode = 0;
	lcd_ctl(lcd_ctl.w);
	LCD_ADDX = 0;
	LCD_ADDY = 0;

	for (i = 0; i < LCD_XSIZE * LCD_YSIZE; i++) LCD_DATA = c;

	return 0;
}
/*
 * Name								: write_a
 * Description				: ---
 * Author							: XiaomaGee.
 *
 * History
 * -------------------
 * Rev								: 0.00
 * Date								: 08/26/2012
 * 
 * create.
 * -------------------
 */
static int
write_a(void)
{
	lcd_ctl.b.write_buf = 0;

	lcd_ctl(lcd_ctl.w);

	return 0;
}
/*
 * Name								: write_b
 * Description				: ---
 * Author							: XiaomaGee.
 *
 * History
 * -------------------
 * Rev								: 0.00
 * Date								: 08/26/2012
 * 
 * create.
 * -------------------
 */
static int
write_b(void)
{
	lcd_ctl.b.write_buf = 1;

	lcd_ctl(lcd_ctl.w);

	return 0;
}

/*
 * Name								: change
 * Description				: ---
 * Author							: XiaomaGee.
 *
 * History
 * -------------------
 * Rev								: 0.00
 * Date								: 08/26/2012
 * 
 * create.
 * -------------------
 */
void change(void)
{
	static int i = 0;

	if (i++ % 2) {
		lcd_ctl.b.disp_buf = 1;
		lcd_ctl.b.write_buf = 0;
		LCD_CTL = lcd_ctl.w;
	}else {
		lcd_ctl.b.disp_buf = 0;
		lcd_ctl.b.write_buf = 1;
		LCD_CTL = lcd_ctl.w;
	}
}
