/*
 * File								: spi3.c
 * Description				: This file is iHMI43 sd card driver.
 * Author							: XiaomaGee@Gmail.com
 * Copyright					:
 *
 * History
 *--------------------
 * Rev								: 0.00
 * Date								: 05/9/2012
 *
 * create.
 *--------------------
 */
//-----------------Include files-------------------------//
#include "..\include\stm32f10x_reg.h"
#include "..\include\spi3.h"

#include <stdio.h>

//---------------- Function Prototype ------------------//
static int initialize_spi3(void);
static int write(int number, unsigned char * buf);
static unsigned char send_data(unsigned char data);

//-----------------Variable-----------------------------//  
SPI3_T spi3 = {
	.initialize = initialize_spi3,
	.write = write,
	.send_data = send_data
};

//-----------------Function-----------------------------//
/*
 * Name										: initialize_spi3
 * Description						: ---
 * Author									: XiaomaGee.
 *
 * History
 * -----------------------
 * Rev										: 0.00
 * Date										: 03/05/2012
 * 
 * create.
 * ----------------------
 */
static int initialize_spi3(void)
{
	RCC->APB2ENR.B.IOPBEN = 1;             //Enable GPIOB clocks
	RCC->APB1ENR.B.SPI3EN = 1;

	//enable SW / disable JTAG
	AFIO->MAPR.B.SWJ_CFG = 2;

	GPIOA->CRH.B.MODE15 = 0x3;           //NSS 50M
	GPIOA->CRH.B.CNF15 = 0x0;            //10ùģʽ
	GPIOB->CRL.B.MODE3 = 0x3;            //CSK 50M
	GPIOB->CRL.B.CNF3 = 0x2;             //10ùģʽ
	GPIOB->CRL.B.MODE5 = 0x3;            //MOSI 50M
	GPIOB->CRL.B.CNF5 = 0x2;             //10ùģʽ

	GPIOB->CRL.B.MODE4 = 0x0;            //MISO
	GPIOB->CRL.B.CNF4 = 0x1;             //01ģʽ(λ״̬)
	//10/ģʽ


	SPI3->CR1.B.BR = 7;                  //000 fPCLK/2
	//001 fPCLK/4
	//010 fPCLK/8
	//011 fPCLK/16
	//100 fPCLK/32
	//101 fPCLK/64
	//110 fPCLK/128	36M/128
	//111 fPCLK/256
	SPI3->CR1.B.BIDIMODE = 0;           //0ѡ˫˫ģʽ
	SPI3->CR1.B.CPOL = 0;
	SPI3->CR1.B.CPHA = 0;
	SPI3->CR1.B.DFF = 0;                //1ʹ16λ֡ʽз/գ
	//0ʹ8λ֡ʽз/գ
	SPI3->CR1.B.LSBFIRST = 0;           //0ȷMSB
	SPI3->CR2.B.SSOE = 1;               //1豸ʱģʽSS
	SPI3->CR1.B.MSTR = 1;               //1Ϊ豸

	SPI3->CR1.B.SSM = 1;
	SPI3->CR1.B.SSI = 1;    

	SPI3->CR1.B.SPE = 1;               //1SPI豸

	SPI3_CS_ON;

	return 0;
}
/*
 * Name										: send_data
 * Description						: ---
 * Author									: XiaomaGee.
 *
 * History
 * -----------------------
 * Rev										: 0.00
 * Date										: 03/05/2012
 * 
 * create.
 * ----------------------
 */
static unsigned char send_data(unsigned char data)
{
	while (!(SPI3->SR.B.TXE == 1)) ;

	SPI3->DR = data;

	while (!(SPI3->SR.B.RXNE == 1)) ;

	return SPI3->DR;
}
/*
 * Name										: write
 * Description						: ---
 * Author									: XiaomaGee.
 *
 * History
 * -----------------------
 * Rev										: 0.00
 * Date										: 03/05/2012
 * 
 * create.
 * ----------------------
 */
static int write(int number, unsigned char * buf)
{
	int i;

	SPI3_CS_OFF;

	for (i = 0; i < number; i++) buf[i] = send_data(buf[i]);

	SPI3_CS_ON;

	return 0;
}
